@@ -10,6 +10,14 @@ class DependencyReflector(Reflector):
 		for root, dirs, files in os.walk(self.repo_dir):
 			if 'node_modules' in root:
 				continue
+			if 'gem' in dirs:
+				dirs.remove('gem')
+			if 'gems' in dirs:
+				dirs.remove('gems')
+			if 'plugin' in dirs:
+				dirs.remove('plugin')
+			if 'plugins' in dirs:
+				dirs.remove('plugins')
 			if '.git' in dirs:
 				dirs.remove('.git')
 			if '.git' in files:
@@ -24,17 +32,12 @@ class DependencyReflector(Reflector):
 	def _get_language_from_file(self, name):
 		if name == 'package.json':
 			return 'nodejs'
-		elif name == 'requirements.txt':
+		elif name.endswith('requirements.txt'):
 			return 'python'
-		elif name == 'Gemfile':
+		elif name == 'Gemfile' or name == 'Rakefile':
 			return 'ruby'
 		elif name == 'pom.xml':
 			return 'java'
 
 	def _is_package_manager_file(self, name):
-		return name in [
-			'package.json',
-			'requirements.txt',
-			'Gemfile',
-			'pom.xml'
-		]
+		return name in ['package.json', 'Gemfile', 'Rakefile', 'pom.xml'] or name.endswith('requirements.txt')
