@@ -4,11 +4,11 @@
 Wraps the git and hg client.
 
 Usage:
-  koality help
-  koality generate-config
-  koality commit [ARGS...]
-  koality push [ARGS...]
-  koality <command> [ARGS...]
+  ko help
+  ko generate 
+  ko commit [ARGS...]
+  ko push [ARGS...]
+  ko <command> [ARGS...]
 
 Options:
   -h --help    Show this message
@@ -16,7 +16,7 @@ Options:
 
 Details:
   help                - print this message
-  generate-config     - attempt to autocreate a config koality.yml in the 
+  generate           - attempt to autocreate a config koality.yml in the 
                         repo root that will work in most cases but in some
                         instances may need modifications to properly work
   push                - perform a push that is automatically pre verified
@@ -28,16 +28,16 @@ full_doc = """Koality client that simplfies workflows.
 Wraps the git and hg client.
 
 Usage:
-  koality help
-  koality login
-  koality upload-keys
-  koality generate-config
-  koality commit [ARGS...]
-  koality push [ARGS...]
-  koality push-unchecked [ARGS...]
-  koality test [ARGS...]
-  koality update
-  koality <command> [ARGS...]
+  ko help
+  ko login
+  ko upload-keys
+  ko generate
+  ko commit [ARGS...]
+  ko push [ARGS...]
+  ko push-unchecked [ARGS...]
+  ko test [ARGS...]
+  ko update
+  ko <command> [ARGS...]
 
 Options:
   -h --help    Show this message
@@ -47,7 +47,7 @@ Details:
   help                - print this message
   login               - login to your Koality instance to perform commands
   upload-keys         - auto upload ssh keys to your Koality instance
-  autogenerate-config - attempt to autocreate a config koality.yml in the 
+  generate           - attempt to autocreate a config koality.yml in the 
                         repo root that will work in most cases but in some
                         instances may need modifications to properly work
   push                - perform a push that is automatically pre verified
@@ -104,7 +104,8 @@ class CliHandler(object):
 			elif subprocess.call(["hg", "root"], stdout=FNULL, stderr=subprocess.STDOUT) == 0:
 				return 'hg'
 			else:
-				print "fatal: not a git or hg repository."
+				print "fatal: unable to identify version control system to use."
+				print "Try manually calling your VCS cli to invoke this command."
 				raise IOError
 
 	def help(self):
@@ -116,7 +117,7 @@ class CliHandler(object):
 	def upload_keys(self):
 		raise NotImplementedError
 
-	def generate_config(self):
+	def generate(self):
 		try:
 			vcs = self._repo_type()
 			if vcs == 'git':
